"""
Utility and extra functions here
"""

import shelve
from .spooldb import SpoolDB

def open(filename=None, data={}, flag='c', mode=None, format='pickle', *args, **kwargs):
    """
    Open a SpoolDB.
    """
    return SpoolDB(filename, data=data, flag=flag, mode=mode, format=format, *args, **kwargs)

def openshelve(filename=None, data={}, flag='c', mode=None, format='pickle', *args, **kwargs):
    """
    Open a shelve instance with SpoolDB as the backend.
    """
    return shelve.Shelf(SpoolDB(filename, data=data, flag=flag, mode=mode, format=format, *args, **kwargs))


"""
Everything needed together for SpoolDB

With a little test program built in.

It contains the database and some functions
"""

from .spooldb import SpoolDB
from .dbfunc import open, openshelve

VERSION_INFO = (0, 1, 0)
VERSION = '.'.join(map(str, VERSION_INFO))
__version__ = VERSION

__author__ = "MXPSQL"

# Example program embedded
if __name__ == "__main__":
    with open('test.db', flag='c', format='json') as db:
        db["yes"] = "yes"
        db["high heel"] = "spool pumps"
        db["i"] = {
            "map": True,
            "list": [1, 2, 3],
            "tdb": {
                'ls': "true",
                "dir": True,
                "pax": True,
                "node": 'yes'
            }
        }
        db["lisp"] = ["common lisp", "scheme", "clojure"]

        for i in range(0, 5):
            db[i] = i


import setuptools as st
__project__ = "SpoolDB"
__version__ = "0.1.0"
__description__ = "Python persistent dictionary (a key value store)"
__packages__ = ["spooldb"]
__author__ = "MXPSQL"
__author__email__ = "2000onetechguy@gmail.com"
__keywords__ = ["Dict", "Persistent", "Database", "JSON", "CSV", "Shelf", "Pickle"]
__source__ = "https://github.com/MOALib/SpoolDB"
__classifiers__ = [
    "Development Status :: 3 - Alpha",
    "Intended Audience :: Developers",
    "License :: OSI Approved :: MIT License",
    "Operating System :: OS Independent",
    "Programming Language :: Python :: 3.6",
]

st.setup(
    name=__project__,
    version=__version__,
    description=__description__,
    packages=__packages__,
    author=__author__,
    author_email=__author__email__,
    url=__source__,
    keywords=__keywords__,
    classifiers=__classifiers__,
)